==> oci-java-sdk-shaded-full-3.40.0-sources.jar: com/oracle/bmc/stackmonitoring/requests/UpdateMonitoredResourceTypeRequest.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.stackmonitoring.requests;

import com.oracle.bmc.stackmonitoring.model.*;
/**
 * <b>Example: </b>Click <a
 * href="https://docs.cloud.oracle.com/en-us/iaas/tools/java-sdk-examples/3.40.0/stackmonitoring/UpdateMonitoredResourceTypeExample.java.html"
 * target="_blank" rel="noopener noreferrer">here</a> to see how to use
 * UpdateMonitoredResourceTypeRequest.
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20210330")
public class UpdateMonitoredResourceTypeRequest
        extends com.oracle.bmc.requests.BmcRequest<
                com.oracle.bmc.stackmonitoring.model.UpdateMonitoredResourceTypeDetails> {

    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of
     * monitored resource type.
     */
    private String monitoredResourceTypeId;

    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of
     * monitored resource type.
     */
    public String getMonitoredResourceTypeId() {
        return monitoredResourceTypeId;
    }
    /** The information to be updated for the given resource type id. */
    private com.oracle.bmc.stackmonitoring.model.UpdateMonitoredResourceTypeDetails
            updateMonitoredResourceTypeDetails;

    /** The information to be updated for the given resource type id. */
    public com.oracle.bmc.stackmonitoring.model.UpdateMonitoredResourceTypeDetails
            getUpdateMonitoredResourceTypeDetails() {
        return updateMonitoredResourceTypeDetails;
    }
    /**
     * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the {@code
     * if-match} parameter to the value of the etag from a previous GET or POST response for that
     * resource. The resource will be updated or deleted only if the etag you provide matches the
     * resource's current etag value.
     */
    private String ifMatch;

    /**
     * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the {@code
     * if-match} parameter to the value of the etag from a previous GET or POST response for that
     * resource. The resource will be updated or deleted only if the etag you provide matches the
     * resource's current etag value.
     */
    public String getIfMatch() {
        return ifMatch;
    }
    /**
     * Unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
     * particular request, please provide the request ID.
     */
    private String opcRequestId;

    /**
     * Unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
     * particular request, please provide the request ID.
     */
    public String getOpcRequestId() {
        return opcRequestId;
    }

    /**
     * Alternative accessor for the body parameter.
     *
     * @return body parameter
     */
    @Override
    @com.oracle.bmc.InternalSdk
    public com.oracle.bmc.stackmonitoring.model.UpdateMonitoredResourceTypeDetails getBody$() {
        return updateMonitoredResourceTypeDetails;
    }

    public static class Builder
            implements com.oracle.bmc.requests.BmcRequest.Builder<
                    UpdateMonitoredResourceTypeRequest,
                    com.oracle.bmc.stackmonitoring.model.UpdateMonitoredResourceTypeDetails> {
        private com.oracle.bmc.http.client.RequestInterceptor invocationCallback = null;
        private com.oracle.bmc.retrier.RetryConfiguration retryConfiguration = null;

        /**
         * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of
         * monitored resource type.
         */
        private String monitoredResourceTypeId = null;

        /**
         * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of
         * monitored resource type.
         *
         * @param monitoredResourceTypeId the value to set
         * @return this builder instance
         */
        public Builder monitoredResourceTypeId(String monitoredResourceTypeId) {
            this.monitoredResourceTypeId = monitoredResourceTypeId;
            return this;
        }

        /** The information to be updated for the given resource type id. */
        private com.oracle.bmc.stackmonitoring.model.UpdateMonitoredResourceTypeDetails
                updateMonitoredResourceTypeDetails = null;

        /**
         * The information to be updated for the given resource type id.
         *
         * @param updateMonitoredResourceTypeDetails the value to set
         * @return this builder instance
         */
        public Builder updateMonitoredResourceTypeDetails(
                com.oracle.bmc.stackmonitoring.model.UpdateMonitoredResourceTypeDetails
                        updateMonitoredResourceTypeDetails) {
            this.updateMonitoredResourceTypeDetails = updateMonitoredResourceTypeDetails;
            return this;
        }

        /**
         * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
         * {@code if-match} parameter to the value of the etag from a previous GET or POST response
         * for that resource. The resource will be updated or deleted only if the etag you provide
         * matches the resource's current etag value.
         */
        private String ifMatch = null;

        /**
         * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
         * {@code if-match} parameter to the value of the etag from a previous GET or POST response
         * for that resource. The resource will be updated or deleted only if the etag you provide
         * matches the resource's current etag value.
         *
         * @param ifMatch the value to set
         * @return this builder instance
         */
        public Builder ifMatch(String ifMatch) {
            this.ifMatch = ifMatch;
            return this;
        }

        /**
         * Unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
         * particular request, please provide the request ID.
         */
        private String opcRequestId = null;

        /**
         * Unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
         * particular request, please provide the request ID.
         *
         * @param opcRequestId the value to set
         * @return this builder instance
         */
        public Builder opcRequestId(String opcRequestId) {
            this.opcRequestId = opcRequestId;
            return this;
        }

        /**
         * Set the invocation callback for the request to be built.
         *
         * @param invocationCallback the invocation callback to be set for the request
         * @return this builder instance
         */
        public Builder invocationCallback(
                com.oracle.bmc.http.client.RequestInterceptor invocationCallback) {
            this.invocationCallback = invocationCallback;
            return this;
        }

        /**
         * Set the retry configuration for the request to be built.
         *
         * @param retryConfiguration the retry configuration to be used for the request
         * @return this builder instance
         */
        public Builder retryConfiguration(
                com.oracle.bmc.retrier.RetryConfiguration retryConfiguration) {
            this.retryConfiguration = retryConfiguration;
            return this;
        }

        /**
         * Copy method to populate the builder with values from the given instance.
         *
         * @return this builder instance
         */
        public Builder copy(UpdateMonitoredResourceTypeRequest o) {
            monitoredResourceTypeId(o.getMonitoredResourceTypeId());
            updateMonitoredResourceTypeDetails(o.getUpdateMonitoredResourceTypeDetails());
            ifMatch(o.getIfMatch());
            opcRequestId(o.getOpcRequestId());
            invocationCallback(o.getInvocationCallback());
            retryConfiguration(o.getRetryConfiguration());
            return this;
        }

        /**
         * Build the instance of UpdateMonitoredResourceTypeRequest as configured by this builder
         *
         * <p>Note that this method takes calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#buildWithoutInvocationCallback} does not.
         *
         * <p>This is the preferred method to build an instance.
         *
         * @return instance of UpdateMonitoredResourceTypeRequest
         */
        public UpdateMonitoredResourceTypeRequest build() {
            UpdateMonitoredResourceTypeRequest request = buildWithoutInvocationCallback();
            request.setInvocationCallback(invocationCallback);
            request.setRetryConfiguration(retryConfiguration);
            return request;
        }

        /**
         * Alternative setter for the body parameter.
         *
         * @param body the body parameter
         * @return this builder instance
         */
        @com.oracle.bmc.InternalSdk
        public Builder body$(
                com.oracle.bmc.stackmonitoring.model.UpdateMonitoredResourceTypeDetails body) {
            updateMonitoredResourceTypeDetails(body);
            return this;
        }

        /**
         * Build the instance of UpdateMonitoredResourceTypeRequest as configured by this builder
         *
         * <p>Note that this method does not take calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#build} does
         *
         * @return instance of UpdateMonitoredResourceTypeRequest
         */
        public UpdateMonitoredResourceTypeRequest buildWithoutInvocationCallback() {
            UpdateMonitoredResourceTypeRequest request = new UpdateMonitoredResourceTypeRequest();
            request.monitoredResourceTypeId = monitoredResourceTypeId;
            request.updateMonitoredResourceTypeDetails = updateMonitoredResourceTypeDetails;
            request.ifMatch = ifMatch;
            request.opcRequestId = opcRequestId;
            return request;
            // new UpdateMonitoredResourceTypeRequest(monitoredResourceTypeId,
            // updateMonitoredResourceTypeDetails, ifMatch, opcRequestId);
        }
    }

    /**
     * Return an instance of {@link Builder} that allows you to modify request properties.
     *
     * @return instance of {@link Builder} that allows you to modify request properties.
     */
    public Builder toBuilder() {
        return new Builder()
                .monitoredResourceTypeId(monitoredResourceTypeId)
                .updateMonitoredResourceTypeDetails(updateMonitoredResourceTypeDetails)
                .ifMatch(ifMatch)
                .opcRequestId(opcRequestId);
    }

    /**
     * Return a new builder for this request object.
     *
     * @return builder for the request object
     */
    public static Builder builder() {
        return new Builder();
    }

    @Override
    public String toString() {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("(");
        sb.append("super=").append(super.toString());
        sb.append(",monitoredResourceTypeId=").append(String.valueOf(this.monitoredResourceTypeId));
        sb.append(",updateMonitoredResourceTypeDetails=")
                .append(String.valueOf(this.updateMonitoredResourceTypeDetails));
        sb.append(",ifMatch=").append(String.valueOf(this.ifMatch));
        sb.append(",opcRequestId=").append(String.valueOf(this.opcRequestId));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof UpdateMonitoredResourceTypeRequest)) {
            return false;
        }

        UpdateMonitoredResourceTypeRequest other = (UpdateMonitoredResourceTypeRequest) o;
        return super.equals(o)
                && java.util.Objects.equals(
                        this.monitoredResourceTypeId, other.monitoredResourceTypeId)
                && java.util.Objects.equals(
                        this.updateMonitoredResourceTypeDetails,
                        other.updateMonitoredResourceTypeDetails)
                && java.util.Objects.equals(this.ifMatch, other.ifMatch)
                && java.util.Objects.equals(this.opcRequestId, other.opcRequestId);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.monitoredResourceTypeId == null
                                ? 43
                                : this.monitoredResourceTypeId.hashCode());
        result =
                (result * PRIME)
                        + (this.updateMonitoredResourceTypeDetails == null
                                ? 43
                                : this.updateMonitoredResourceTypeDetails.hashCode());
        result = (result * PRIME) + (this.ifMatch == null ? 43 : this.ifMatch.hashCode());
        result = (result * PRIME) + (this.opcRequestId == null ? 43 : this.opcRequestId.hashCode());
        return result;
    }
}

==> oci-java-sdk-shaded-full-3.48.0-sources.jar: com/oracle/bmc/stackmonitoring/requests/UpdateMonitoredResourceTypeRequest.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.stackmonitoring.requests;

import com.oracle.bmc.stackmonitoring.model.*;
/**
 * <b>Example: </b>Click <a
 * href="https://docs.cloud.oracle.com/en-us/iaas/tools/java-sdk-examples/latest/stackmonitoring/UpdateMonitoredResourceTypeExample.java.html"
 * target="_blank" rel="noopener noreferrer">here</a> to see how to use
 * UpdateMonitoredResourceTypeRequest.
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20210330")
public class UpdateMonitoredResourceTypeRequest
        extends com.oracle.bmc.requests.BmcRequest<
                com.oracle.bmc.stackmonitoring.model.UpdateMonitoredResourceTypeDetails> {

    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of
     * monitored resource type.
     */
    private String monitoredResourceTypeId;

    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of
     * monitored resource type.
     */
    public String getMonitoredResourceTypeId() {
        return monitoredResourceTypeId;
    }
    /** The information to be updated for the given resource type id. */
    private com.oracle.bmc.stackmonitoring.model.UpdateMonitoredResourceTypeDetails
            updateMonitoredResourceTypeDetails;

    /** The information to be updated for the given resource type id. */
    public com.oracle.bmc.stackmonitoring.model.UpdateMonitoredResourceTypeDetails
            getUpdateMonitoredResourceTypeDetails() {
        return updateMonitoredResourceTypeDetails;
    }
    /**
     * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the {@code
     * if-match} parameter to the value of the etag from a previous GET or POST response for that
     * resource. The resource will be updated or deleted only if the etag you provide matches the
     * resource's current etag value.
     */
    private String ifMatch;

    /**
     * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the {@code
     * if-match} parameter to the value of the etag from a previous GET or POST response for that
     * resource. The resource will be updated or deleted only if the etag you provide matches the
     * resource's current etag value.
     */
    public String getIfMatch() {
        return ifMatch;
    }
    /**
     * Unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
     * particular request, please provide the request ID.
     */
    private String opcRequestId;

    /**
     * Unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
     * particular request, please provide the request ID.
     */
    public String getOpcRequestId() {
        return opcRequestId;
    }

    /**
     * Alternative accessor for the body parameter.
     *
     * @return body parameter
     */
    @Override
    @com.oracle.bmc.InternalSdk
    public com.oracle.bmc.stackmonitoring.model.UpdateMonitoredResourceTypeDetails getBody$() {
        return updateMonitoredResourceTypeDetails;
    }

    public static class Builder
            implements com.oracle.bmc.requests.BmcRequest.Builder<
                    UpdateMonitoredResourceTypeRequest,
                    com.oracle.bmc.stackmonitoring.model.UpdateMonitoredResourceTypeDetails> {
        private com.oracle.bmc.http.client.RequestInterceptor invocationCallback = null;
        private com.oracle.bmc.retrier.RetryConfiguration retryConfiguration = null;

        /**
         * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of
         * monitored resource type.
         */
        private String monitoredResourceTypeId = null;

        /**
         * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of
         * monitored resource type.
         *
         * @param monitoredResourceTypeId the value to set
         * @return this builder instance
         */
        public Builder monitoredResourceTypeId(String monitoredResourceTypeId) {
            this.monitoredResourceTypeId = monitoredResourceTypeId;
            return this;
        }

        /** The information to be updated for the given resource type id. */
        private com.oracle.bmc.stackmonitoring.model.UpdateMonitoredResourceTypeDetails
                updateMonitoredResourceTypeDetails = null;

        /**
         * The information to be updated for the given resource type id.
         *
         * @param updateMonitoredResourceTypeDetails the value to set
         * @return this builder instance
         */
        public Builder updateMonitoredResourceTypeDetails(
                com.oracle.bmc.stackmonitoring.model.UpdateMonitoredResourceTypeDetails
                        updateMonitoredResourceTypeDetails) {
            this.updateMonitoredResourceTypeDetails = updateMonitoredResourceTypeDetails;
            return this;
        }

        /**
         * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
         * {@code if-match} parameter to the value of the etag from a previous GET or POST response
         * for that resource. The resource will be updated or deleted only if the etag you provide
         * matches the resource's current etag value.
         */
        private String ifMatch = null;

        /**
         * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
         * {@code if-match} parameter to the value of the etag from a previous GET or POST response
         * for that resource. The resource will be updated or deleted only if the etag you provide
         * matches the resource's current etag value.
         *
         * @param ifMatch the value to set
         * @return this builder instance
         */
        public Builder ifMatch(String ifMatch) {
            this.ifMatch = ifMatch;
            return this;
        }

        /**
         * Unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
         * particular request, please provide the request ID.
         */
        private String opcRequestId = null;

        /**
         * Unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
         * particular request, please provide the request ID.
         *
         * @param opcRequestId the value to set
         * @return this builder instance
         */
        public Builder opcRequestId(String opcRequestId) {
            this.opcRequestId = opcRequestId;
            return this;
        }

        /**
         * Set the invocation callback for the request to be built.
         *
         * @param invocationCallback the invocation callback to be set for the request
         * @return this builder instance
         */
        public Builder invocationCallback(
                com.oracle.bmc.http.client.RequestInterceptor invocationCallback) {
            this.invocationCallback = invocationCallback;
            return this;
        }

        /**
         * Set the retry configuration for the request to be built.
         *
         * @param retryConfiguration the retry configuration to be used for the request
         * @return this builder instance
         */
        public Builder retryConfiguration(
                com.oracle.bmc.retrier.RetryConfiguration retryConfiguration) {
            this.retryConfiguration = retryConfiguration;
            return this;
        }

        /**
         * Copy method to populate the builder with values from the given instance.
         *
         * @return this builder instance
         */
        public Builder copy(UpdateMonitoredResourceTypeRequest o) {
            monitoredResourceTypeId(o.getMonitoredResourceTypeId());
            updateMonitoredResourceTypeDetails(o.getUpdateMonitoredResourceTypeDetails());
            ifMatch(o.getIfMatch());
            opcRequestId(o.getOpcRequestId());
            invocationCallback(o.getInvocationCallback());
            retryConfiguration(o.getRetryConfiguration());
            return this;
        }

        /**
         * Build the instance of UpdateMonitoredResourceTypeRequest as configured by this builder
         *
         * <p>Note that this method takes calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#buildWithoutInvocationCallback} does not.
         *
         * <p>This is the preferred method to build an instance.
         *
         * @return instance of UpdateMonitoredResourceTypeRequest
         */
        public UpdateMonitoredResourceTypeRequest build() {
            UpdateMonitoredResourceTypeRequest request = buildWithoutInvocationCallback();
            request.setInvocationCallback(invocationCallback);
            request.setRetryConfiguration(retryConfiguration);
            return request;
        }

        /**
         * Alternative setter for the body parameter.
         *
         * @param body the body parameter
         * @return this builder instance
         */
        @com.oracle.bmc.InternalSdk
        public Builder body$(
                com.oracle.bmc.stackmonitoring.model.UpdateMonitoredResourceTypeDetails body) {
            updateMonitoredResourceTypeDetails(body);
            return this;
        }

        /**
         * Build the instance of UpdateMonitoredResourceTypeRequest as configured by this builder
         *
         * <p>Note that this method does not take calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#build} does
         *
         * @return instance of UpdateMonitoredResourceTypeRequest
         */
        public UpdateMonitoredResourceTypeRequest buildWithoutInvocationCallback() {
            UpdateMonitoredResourceTypeRequest request = new UpdateMonitoredResourceTypeRequest();
            request.monitoredResourceTypeId = monitoredResourceTypeId;
            request.updateMonitoredResourceTypeDetails = updateMonitoredResourceTypeDetails;
            request.ifMatch = ifMatch;
            request.opcRequestId = opcRequestId;
            return request;
            // new UpdateMonitoredResourceTypeRequest(monitoredResourceTypeId,
            // updateMonitoredResourceTypeDetails, ifMatch, opcRequestId);
        }
    }

    /**
     * Return an instance of {@link Builder} that allows you to modify request properties.
     *
     * @return instance of {@link Builder} that allows you to modify request properties.
     */
    public Builder toBuilder() {
        return new Builder()
                .monitoredResourceTypeId(monitoredResourceTypeId)
                .updateMonitoredResourceTypeDetails(updateMonitoredResourceTypeDetails)
                .ifMatch(ifMatch)
                .opcRequestId(opcRequestId);
    }

    /**
     * Return a new builder for this request object.
     *
     * @return builder for the request object
     */
    public static Builder builder() {
        return new Builder();
    }

    @Override
    public String toString() {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("(");
        sb.append("super=").append(super.toString());
        sb.append(",monitoredResourceTypeId=").append(String.valueOf(this.monitoredResourceTypeId));
        sb.append(",updateMonitoredResourceTypeDetails=")
                .append(String.valueOf(this.updateMonitoredResourceTypeDetails));
        sb.append(",ifMatch=").append(String.valueOf(this.ifMatch));
        sb.append(",opcRequestId=").append(String.valueOf(this.opcRequestId));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof UpdateMonitoredResourceTypeRequest)) {
            return false;
        }

        UpdateMonitoredResourceTypeRequest other = (UpdateMonitoredResourceTypeRequest) o;
        return super.equals(o)
                && java.util.Objects.equals(
                        this.monitoredResourceTypeId, other.monitoredResourceTypeId)
                && java.util.Objects.equals(
                        this.updateMonitoredResourceTypeDetails,
                        other.updateMonitoredResourceTypeDetails)
                && java.util.Objects.equals(this.ifMatch, other.ifMatch)
                && java.util.Objects.equals(this.opcRequestId, other.opcRequestId);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.monitoredResourceTypeId == null
                                ? 43
                                : this.monitoredResourceTypeId.hashCode());
        result =
                (result * PRIME)
                        + (this.updateMonitoredResourceTypeDetails == null
                                ? 43
                                : this.updateMonitoredResourceTypeDetails.hashCode());
        result = (result * PRIME) + (this.ifMatch == null ? 43 : this.ifMatch.hashCode());
        result = (result * PRIME) + (this.opcRequestId == null ? 43 : this.opcRequestId.hashCode());
        return result;
    }
}
